import java.util.Random;
import java.util.ArrayList;
import java.util.Collections;
import java.io.File;
import java.io.FileWriter;
import java.io.IOException;

public class Tester {
	/**
	 * Prints a comma separated value representation of execution times in the form:
	 * 
	 * n,sort1,sort2,sort3,...,sortN 
	 * 2^0,val,val,val,...,val 2,val,val,val,...,val
	 * 4,val,val,val,...,val 8,val,val,val,...,val 16,val,val,val,...,val and so on.
	 * 
	 * @param durations list of the durations of all algorithms measured as the size
	 *                  of the list increases
	 * @param measures  indicates how many sorting algorithms where tested
	 * @param filename  csv file to be created, example: "test1.csv"
	 */
	public static void printCSV(ArrayList<Long> durations, int measures, String filename) {
		int n = 0;
		File file = new File(filename);
		FileWriter fr;

		try {
			fr = new FileWriter(file);

			fr.write("n");
			System.out.print("n");

			for (int i = 0; i < measures; i++) {
				System.out.print(",sort" + (i + 1));
				fr.write(",sort" + (i + 1));

			}

			for (int i = 0; i < durations.size(); i++) {
				if (i % measures == 0) {
					System.out.println();
					System.out.print("2^" + n);
					fr.write("\n2^" + n);
					n++;
				}
				System.out.print(",");
				System.out.print(durations.get(i));
				fr.write(",");
				fr.write(durations.get(i).toString());
			}
			fr.close();
		} catch (IOException e) {
			e.printStackTrace();
		}

	}

	public static void main(String[] args) {
		Random r = new Random();

		long startTime, duration;
		ArrayList<Long> allDurations = new ArrayList<Long>();

		int n = 1;
		int runs = 15;
		int maxNumber = 1000000000;

		while (runs >= 0) {
			System.out.println("Sorting list of size " + n);

			// Lists of integers to be used per test.
			// Uncomment if you need more
			ArrayList<Integer> list1 = new ArrayList<Integer>();
			ArrayList<Integer> list2 = new ArrayList<Integer>();
			ArrayList<Integer> list3 = new ArrayList<Integer>();
			// ArrayList<Integer> list4 = new ArrayList<Integer>();
			// ArrayList<Integer> list5 = new ArrayList<Integer>();

			for (int i = 0; i < n; i++) {
				int num = r.nextInt(maxNumber);
				list1.add(num);
				list2.add(num);
				list3.add(num);
				// list4.add(num);
				// list5.add(num);
			}

			// 1st Measure
			startTime = System.nanoTime();
			// Measure your sorting algorithm here
			Sorters.selectionSort(list1);
			duration = (System.nanoTime() - startTime);
			allDurations.add(duration);

			// 2nd Measure
			startTime = System.nanoTime();
			// Measure your sorting algorithm here
			Sorters.mergeSort(list2);
			duration = (System.nanoTime() - startTime);
			allDurations.add(duration);
			
			startTime = System.nanoTime();
			// Measure your sorting algorithm here
			Sorters.radixSort(list3);
			duration = (System.nanoTime() - startTime);
			allDurations.add(duration);
			/* 
			 * // 4th Measure startTime = System.nanoTime(); // Measure your sorting
			 * algorithm here duration = (System.nanoTime() - startTime);
			 * allDurations.add(duration);
			 * 
			 * // 5th Measure startTime = System.nanoTime(); // Measure your sorting
			 * algorithm here duration = (System.nanoTime() - startTime);
			 * allDurations.add(duration);
			 */
			n *= 2;
			runs--;
		}

		printCSV(allDurations, 3, "test1.csv");
	}

}
